This directory contains required code from the javascript library three.js.
See http://threejs.org or https://github.com/mrdoob/three.js/

See the file LICENSE for information on license and copyright.

The included files are taken from version r69.
